{ inputs, ... }: {
  generate = { syspath }:
    let
      syscfg = import ./systems/${syspath}/cfg.nix;
      nameValuePair = name: value: { inherit name value; };
    in ({
      "nixos" = {
        nisoxConfigurations."${syscfg.hostname}" =
          inputs.nixpkgs.lib.nixosSystem {
            system = syscfg.system;
            modules = [
              ./modules/shared/syscfg
              ./modules/shared/sops
              ./modules/nixos
              syscfg
              syspath
              inputs.sops-nix.nixosModules.sops
              inputs.home-manager.nixosModules.home-manager
              {
                home-manager.useGlobalPkgs = true;
                home-manager.useUserPackages = true;
                home-manager.extraSpecialArgs = { inherit inputs; };
                home-manager.users = builtins.listToAttrs (map (userConfig:
                  nameValuePair userConfig.username {
                    imports = [
                      ./modules/shared/syscfg
                      ./modules/shared/colors
                      ./modules/home
                      syscfg
                      { usercfg = userConfig; }
                      inputs.nix-colors.homeManagerModule
                      inputs.hyprland.homeManagerModules.default
                    ];
                  }) syscfg.syscfg.users);
              }
            ];
          };
      };

      "macos" = inputs.darwin.lib.darwinSystem {
        system = syscfg.system;
        modules = [
          inputs.sops-nix.nixosModules.sops
          syspath
          inputs.home-manager.darwinModules.home-manager
          {
            home-manager.useGlobalPkgs = true;
            home-manager.useUserPackages = true;
            home-manager.extraSpecialArgs = { inherit inputs; };
            home-manager.users.sora = {
              imports = [
                inputs.nix-colors.homeManagerModule
                inputs.hyprland.homeManagerModules
                ./systems/${syspath}/home.nix
              ];
            };
          }
        ];
      };
      "home" = inputs.home-manager.lib.homeManagerConfiguration {
        modules = [ ./modules/home ./systems/${syscfg.hostname}/home.nix ];
      };
      _ = throw "Unsupported system";
    }.${syscfg.type});
}
